@@ -1,4 +1,4 @@
 from __future__ import annotations
 
-from pykronecker.operators import KroneckerProduct, KroneckerDiag, KroneckerSum
-from pykronecker.block import KroneckerBlock, KroneckerBlockDiag
\ No newline at end of file
+from pykronecker.operators import KroneckerProduct, KroneckerDiag, KroneckerSum, KroneckerIdentity
+from pykronecker.block import KroneckerBlock, KroneckerBlockDiag
