@@ -227,17 +227,20 @@ class KroneckerOperator(ABC):
 
     def __pos__(self) -> 'KroneckerOperator':
         """
-        +Obj == Obj
+        `+Obj == Obj`
         """
         return self
 
     def __neg__(self) -> 'KroneckerOperator':
         """
-        -Obj == (-1) * Obj
+        `-Obj == (-1) * Obj`
         """
         return (-1) * self
 
     def __len__(self) -> int:
+        """
+        Get the length of the object.
+        """
         return self.shape[0]
 
     def __str__(self) -> str:
@@ -252,12 +255,12 @@ class KroneckerOperator(ABC):
         this function rather than just the @ operator.
 
         E.g.
-            KroneckerProduct(A, B, C) @ vec(X) == np.matmul(KroneckerProduct(A, B, C), vec(X))
+            `KroneckerProduct(A, B, C) @ vec(X) == np.matmul(KroneckerProduct(A, B, C), vec(X))`
 
         Note that
-            KroneckerProduct(A, B, C) @ X !=  np.matmul(KroneckerProduct(A, B, C), X)
+            `KroneckerProduct(A, B, C) @ X !=  np.matmul(KroneckerProduct(A, B, C), X)`
 
-        and that it does not work with np.dot()
+        and that it does not work with `np.dot()`
         """
 
         A, B = inputs[1], inputs[2]
@@ -301,9 +304,15 @@ class KroneckerOperator(ABC):
             raise ValueError('Axis should be -1, 0, 1 or None')
 
     def copy(self) -> 'KroneckerOperator':
+        """
+        Alias for __copy__
+        """
         return self.__copy__()
 
     def deepcopy(self) -> 'KroneckerOperator':
+        """
+        Alias for __deepcopy__
+        """
         return self.__deepcopy__()
 
     # ----------- STATIC METHODS -----------
